exceptiontools.PitchError
=========================

.. inheritance-diagram:: abjad.tools.exceptiontools.PitchError.PitchError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.PitchError.PitchError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
